/* -*- Mode: IDL; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "domstubs.idl"

/**
 * The nsIDOMElementCSSInlineStyle interface allows access to the inline
 * style information for elements.
 *
 * For more information on this interface please see
 * http://www.w3.org/TR/DOM-Level-2-Style
 */

[scriptable, uuid(99715845-95fc-4a56-aa53-214b65c26e22)]
interface nsIDOMElementCSSInlineStyle : nsISupports
{
  readonly attribute nsIDOMCSSStyleDeclaration  style;
};
