/* -*- Mode: IDL; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "nsIDOMCharacterData.idl"

/**
 * The nsIDOMComment interface inherits from nsIDOMCharacterData and represents 
 * the content of a comment, i.e., all the characters between the starting 
 * '<!--' and ending '-->'.
 * 
 * For more information on this interface please see 
 * http://www.w3.org/TR/DOM-Level-2-Core/
 */

[uuid(e702a5d2-3aa8-4788-b048-2d3b3e6d16f2)]
interface nsIDOMComment : nsIDOMCharacterData
{
};
