/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "nsIURI.idl"

[scriptable, uuid(4bb38cb4-c3cb-4d17-9799-1b3132b39723)]
interface nsIContentURIGrouper : nsISupports
{
    /**
     * Determine the group to which the URI belongs.
     *
     * @param    aURI       the URI to group
     *
     * @returns  the group to which the URI belongs
     */
    AString group(in nsIURI aURI);
};

%{C++
// The contractID for the generic implementation built in to xpcom.
#define NS_HOSTNAME_GROUPER_SERVICE_CONTRACTID "@mozilla.org/content-pref/hostname-grouper;1"
%}
