/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "nsISupports.idl"

interface imgIRequest;

[uuid(dc126d90-0ee0-4683-b942-2fa66e443abc)]
interface imgIOnloadBlocker : nsISupports
{
    /**
     * blockOnload
     * Called when it is appropriate to block onload for the given imgIRequest.
     *
     * @param aRequest
     *        The request that should block onload.
     */
    void blockOnload(in imgIRequest aRequest);

    /**
     * unblockOnload
     * Called when it is appropriate to unblock onload for the given
     * imgIRequest.
     *
     * @param aRequest
     *        The request that should unblock onload.
     */
    void unblockOnload(in imgIRequest aRequest);
};
