/* -*- Mode: IDL; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "domstubs.idl"

/**
 * Empty interface for client side storage. DOMStorage is now ported to WebIDL
 * but we still need an XPConnect interface for casting.
 */

[scriptable, uuid(425a33f0-e0e9-45e7-a95f-9908bd6ae988)]
interface nsIDOMStorage : nsISupports
{
};
